Pollex.CacheAdapter.GenServerCacheAdapter behaviour (pollex v1.0.1)

This module acts as the open api, you can look the data up and specify the columns you wanna get

Summary

Callbacks

lookup(name)

@callback lookup(name :: atom()) :: [map()]

schedule_refresh(interval)

@callback schedule_refresh(interval :: integer()) :: any()