Pollex.SrcAdapter.CSVFileSourceAdapter behaviour (pollex v1.0.1)

Summary

Functions

This function reads a csv file of a given path and transforms the input to a elixir map

This functions returns the path to the where the csvs live

Callbacks

load(t)

@callback load(String.t()) :: {:ok, list()} | {:error, any()}

Functions

read_csv(file_path)

@spec read_csv(String.t()) :: {:ok, Enum.t()} | {:error, Exception.t()}

This function reads a csv file of a given path and transforms the input to a elixir map

seed_path()

@spec seed_path() :: Path.t()

This functions returns the path to the where the csvs live