Pollex.CacheAdapter.GenServerCacheAdapter behaviour (pollex v1.0.1)
View SourceThis module acts as the open api, you can look the data up and specify the columns you wanna get
This module acts as the open api, you can look the data up and specify the columns you wanna get