Pollex.SrcAdapter.CSVFileSourceAdapter behaviour (pollex v1.0.1)
View SourceSummary
Functions
This function reads a csv file of a given path and transforms the input to a elixir map
This functions returns the path to the where the csvs live
Callbacks
Functions
@spec read_csv(String.t()) :: {:ok, Enum.t()} | {:error, Exception.t()}
This function reads a csv file of a given path and transforms the input to a elixir map
@spec seed_path() :: Path.t()
This functions returns the path to the where the csvs live