Pollex.SrcAdapter.EctoAdapter behaviour (pollex v1.0.1)
View SourceThis module acts as the data provider it includes functions to initally get the data from the db and referesh it
Summary
Callbacks
@callback load(table :: Ecto.Schema.t(), repo :: module(), columns :: [atom()]) :: {:ok, list()} | {:error, any()}